@@ -49,7 +49,7 @@ end
 
 
 class JbuilderTest < ActiveSupport::TestCase
-  setup do
+  teardown do
     Jbuilder.send :class_variable_set, '@@key_formatter', nil
   end
 
@@ -75,7 +75,7 @@ class JbuilderTest < ActiveSupport::TestCase
     end
 
     assert result.has_key?('content')
-    assert_equal nil, result['content']
+    assert_nil result['content']
   end
 
   test 'multiple keys' do
@@ -99,7 +99,7 @@ class JbuilderTest < ActiveSupport::TestCase
     assert_equal 32, result['age']
   end
 
-  test 'extracting from object using call style for 1.9' do
+  test 'extracting from object using call style' do
     person = Struct.new(:name, :age).new('David', 32)
 
     result = jbuild do |json|
@@ -159,6 +159,25 @@ class JbuilderTest < ActiveSupport::TestCase
     assert_equal 32, result['author']['age']
   end
 
+  test 'nested blocks are additive' do
+    result = jbuild do |json|
+      json.author do
+        json.name do
+          json.first 'David'
+        end
+      end
+
+      json.author do
+        json.name do
+          json.last 'Heinemeier Hansson'
+        end
+      end
+    end
+
+    assert_equal 'David', result['author']['name']['first']
+    assert_equal 'Heinemeier Hansson', result['author']['name']['last']
+  end
+
   test 'support merge! method' do
     result = jbuild do |json|
       json.merge! 'foo' => 'bar'
@@ -713,4 +732,13 @@ class JbuilderTest < ActiveSupport::TestCase
       end
     end
   end
+
+  if RUBY_VERSION >= "2.2.10"
+    test "respects JSON encoding customizations" do
+      # Active Support overrides Time#as_json for custom formatting.
+      # Ensure we call #to_json on the final attributes instead of JSON.dump.
+      result = JSON.load(Jbuilder.encode { |json| json.time Time.parse("2018-05-13 11:51:00.485 -0400") })
+      assert_equal "2018-05-13T11:51:00.485-04:00", result["time"]
+    end
+  end
 end
